--- /tmp/asterisk-1.8.8.2/main/features.c	2011-09-09 16:09:09.000000000 +0000
+++ ./asterisk-1.8.8.2/main/features.c	2012-01-31 16:13:28.000000000 +0000
@@ -127,6 +127,17 @@
 					<option name="p">
 						<para>Play a courtesy tone to <replaceable>channel</replaceable>.</para>
 					</option>
+					<option name="F" argsep="^">
+						<argument name="context" required="false" />
+						<argument name="exten" required="false" />
+						<argument name="priority" required="true" />
+						<para>When the caller hangs up, transfer the <emphasis>called</emphasis> party
+						to the specified destination and <emphasis>start</emphasis> execution at that location.</para>
+						<note>
+							<para>Any channel variables you want the called channel to inherit from the caller channel must be
+							prefixed with one or two underbars ('_').</para>
+						</note>
+					</option>
 					<option name="h">
 						<para>Allow the called party to hang up by sending the
 						<replaceable>*</replaceable> DTMF digit.</para>
@@ -744,6 +755,13 @@
  	}
 }
 
+static void replace_macro_delimiter(char *s)
+{
+	for (; *s; s++)
+		if (*s == '^')
+			*s = ',';
+}
+
 static const struct ast_datastore_info dial_features_info = {
  	.type = "dial-features",
  	.destroy = dial_features_destroy,
@@ -7126,17 +7144,20 @@
 	OPT_CALLEE_PARK = (1 << 9),
 	OPT_CALLER_PARK = (1 << 10),
 	OPT_CALLEE_KILL = (1 << 11),
+	OPT_CALLEE_GO_ON = (1 << 12),
 };
  
 enum {
 	OPT_ARG_DURATION_LIMIT = 0,
 	OPT_ARG_DURATION_STOP,
+	OPT_ARG_CALLEE_GO_ON,
 	/* note: this entry _MUST_ be the last one in the enum */
 	OPT_ARG_ARRAY_SIZE,
 };
 
 AST_APP_OPTIONS(bridge_exec_options, BEGIN_OPTIONS
 	AST_APP_OPTION('p', BRIDGE_OPT_PLAYTONE),
+	AST_APP_OPTION_ARG('F', OPT_CALLEE_GO_ON, OPT_ARG_CALLEE_GO_ON),
 	AST_APP_OPTION('h', OPT_CALLEE_HANGUP),
 	AST_APP_OPTION('H', OPT_CALLER_HANGUP),
 	AST_APP_OPTION('k', OPT_CALLEE_PARK),
@@ -7397,16 +7418,22 @@
 
 	/* the bridge has ended, set BRIDGERESULT to SUCCESS. If the other channel has not been hung up, return it to the PBX */
 	pbx_builtin_setvar_helper(chan, "BRIDGERESULT", "SUCCESS");
-	if (!ast_check_hangup(final_dest_chan) && !ast_test_flag(&opts, OPT_CALLEE_KILL)) {
-		ast_debug(1, "starting new PBX in %s,%s,%d for chan %s\n", 
-			final_dest_chan->context, final_dest_chan->exten, 
-			final_dest_chan->priority, final_dest_chan->name);
-
-		if (ast_pbx_start(final_dest_chan) != AST_PBX_SUCCESS) {
-			ast_log(LOG_WARNING, "FAILED continuing PBX on dest chan %s\n", final_dest_chan->name);
-			ast_hangup(final_dest_chan);
-		} else
-			ast_debug(1, "SUCCESS continuing PBX on chan %s\n", final_dest_chan->name);
+	if (!ast_check_hangup(final_dest_chan)) {
+		if (ast_test_flag(&opts, OPT_CALLEE_GO_ON)) {
+			replace_macro_delimiter(opt_args[OPT_ARG_CALLEE_GO_ON]);
+			ast_parseable_goto(final_dest_chan, opt_args[OPT_ARG_CALLEE_GO_ON]);
+			ast_pbx_start(final_dest_chan);
+		} else if (!ast_test_flag(&opts, OPT_CALLEE_KILL)) {
+			ast_debug(1, "starting new PBX in %s,%s,%d for chan %s\n", 
+				final_dest_chan->context, final_dest_chan->exten, 
+				final_dest_chan->priority, final_dest_chan->name);
+
+			if (ast_pbx_start(final_dest_chan) != AST_PBX_SUCCESS) {
+				ast_log(LOG_WARNING, "FAILED continuing PBX on dest chan %s\n", final_dest_chan->name);
+				ast_hangup(final_dest_chan);
+			} else
+				ast_debug(1, "SUCCESS continuing PBX on chan %s\n", final_dest_chan->name);
+		}
 	} else {
 		ast_debug(1, "hangup chan %s since the other endpoint has hung up or the x flag was passed\n", final_dest_chan->name);
 		ast_hangup(final_dest_chan);
